pub fn initialize(session: &VortexSession)Expand description
Register vortex-arrow’s session extensions into session.
This eagerly registers the ArrowSession, which is otherwise created lazily on first use.
pub fn initialize(session: &VortexSession)Register vortex-arrow’s session extensions into session.
This eagerly registers the ArrowSession, which is otherwise created lazily on first use.